\name{check_agreement}
\alias{check_agreement}

\title{
 Checking agreement between RTPCR/QuantiGene data and sequencing data
}
\description{
 This function checks the correlation between gene expression measures obtained from different quantitative platforms,
 and compare the correlations before and after bias correction, to see whether thereis any improvement in cross-platform consistency. 
}
\usage{
check_agreement(checkdat, grpn = 3, cor.method = "pearson")
}

\arguments{
  \item{checkdat}{
 A dataframe with 3 columns. For example, column 1 is gene expression levels from RTPCR, column 2 is uncorrected gene expression levels from sequencing,
 column 3 is corrected gene expression levels from sequencing.
}
  \item{grpn}{
 Number of groups to divide the data (default is 3). Groups are divided according to the fold change before and after bias correction. 
}
  \item{cor.method}{
 Type of correlation coeffcient (covariance) to calculate, default is "pearson". Could also be "kendall" or "spearman".
}
}
\details{
}
\value{
 A numeric matrix with 3 columns: correlation with uncorrected data, correlation with corrected data, and percentage improvement. Each row represents calculations for a group of data with corresponding fold change, except for the last row, which is calcualetd from all the data.  
}
\references{
}
\author{
Wei Zheng, Lisa Chung, Hongyu Zhao
}
\note{
}


\seealso{
}
\examples{
\donttest{
## data is not provided
rnaseq <- read.table("MAQC_pcg_genes_expr.txt", header=T)
rtpcr <- read.table("RTPCR_result_cleaned.txt", header=T)
guce <- read.table("ENS59_Gene_length_GC_dinuc.txt", header=T)

low.b <- which(apply(log(rnaseq[,1:7]),1,min) < -10)
low.rtb <- which(apply(log(rtpcr[,5:8]),1,mean) == -Inf)
common.b <- intersect(rownames(rtpcr)[-low.rtb], rownames(rnaseq)[-low.b])

biasg <- guce[match(rownames(rnaseq), guce[,1]),]
biasg[,2] <- log(biasg[,2])
colnames(biasg)[2] <- "log_L"

crt.brain <- gampc(apply(log(rnaseq[-low.b, 1:7]),1,mean), biasg[-low.b,2], biasg[-low.b,3:19])

rtid.b <- match(common.b, rownames(rtpcr))
sqid.b <- match(common.b, rownames(rnaseq))
rt.brain <- apply(log(rtpcr[rtid.b, 5:8]), 1, mean) #delta_CT.

seq.b <- apply(log(rnaseq[sqid.b,1:7]),1,mean)
crt.b <- crt.brain[match(common.b, rownames(crt.brain)),1]
br.dat <-cbind(rt.brain, seq.b, crt.b)
check.agreement(br.dat)
}
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
