\name{gampc}
\alias{gampc}
\title{
 Using generalized additive model combined with principal component analysis to correct for various biases in the gene expression levels from RNA-Seq data.
}
\description{
This function regress the gene expression levels from RNA-Seq data (usually in logRPKM scale) on various bias facors such as log(gene length), GC content, and dinucleotide frequencies in the gene using generalized additive model. Since some bias factors may be highly correlated, such as GC content and GC frequency, PCA was first performed on a subset of bias factors before GAM regression.
}

\usage{
gampc(ymat, xmat1, xmat2, num.pc = NULL)
}

\arguments{
  \item{ymat}{
a dataframe of gene expression levels from RNA-Seq data in log(RPKM) units. Each column represents data from one experiment. 
}
  \item{xmat1}{
a dataframe of bias factors that does not need PCA adjustment. For example, log(gene length) is directly used in GAM without PCA.
}
  \item{xmat2}{
a dataframe of bias factors that needs PCA adjustment. For example, GC content and dinucleotide frequencies.
}
  \item{num.pc}{
Number of principal components to be used in GAM regreesion. Default value is to calculate the mimimal number of PC that explains 95% variance in xmat2.
}
}
\details{
xmat2 was first converted to a number of principal components that are independent from each other, and combined with xmat1 to fit a generalized additive model using smoothing splines. 
}
\value{
This function returns a dataframe with the same dimension as ymat, representing corrected gene expression levels.
}
\references{
}
\author{
Wei Zheng, Lisa Chung, Hongyu Zhao
}
\note{

}


\seealso{

}
\examples{
##see vignette for usage on MAQCtestdata}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
