\name{prime.reweight.counts}
\alias{prime.reweight.counts}

\title{
Calculate gene expression levels from alignemnt files and implementing prime reweighting method
}
\description{
This function calculates counts per gene/transcript from alignment files in bam format, and implements prime reweighting
method as described in Hansen et al. 2010. 
}
\usage{
prime.reweight.counts(infile, annotation, chrMap, group_fac)
}

\arguments{
  \item{infile}{
a character data frame with two columns: id (the name for each experiment), and path (the path to corresponding alignment file)
}
  \item{annotation}{
a dataframe with "Ensembl.Gene.ID", "Ensembl.Transcript.ID", "Ensembl.Exon.ID", "Exon.Chr.Start..bp.", "Exon.Chr.End..bp.", "Chromosome.Name", "Strand", "start", "end", "strand", "chr". Usually obtained from BioConductor.
}
  \item{chrMap}{
a simple character vector with names of each chromosome, must match "Chromosome.Name" in \code{annotation}.
}
  \item{group_fac}{
a character string indicating the unit of counts, e.g. "Ensembl.Transcript.ID"
}
}
\details{
}
\value{
 \item{allCounts}{a data frame with counts per gene for each sample, followed by the prime reweighted counts for each sample.}
 \item{trExp}{a data frame with the same dimention as allCounts, but contains gene expression levels in RPKM unit.}

}
\references{
Hansen KD, Brenner SE, Dudoit S: Biases in Illumina transcriptome sequencing caused by random hexamer priming. Nucleic Acids Res 2010, 38(12):e131.
}
\author{
Wei Zheng, Lisa Chung, Hongyu Zhao
}
\note{
Reads in the alignment files are not probablistically assigned to each transcript. Instead one read may be counted for multiple transcripts.
}



\seealso{

}
\examples{
# if you have a bunch of alignment files in bam format, e.g. brain samples in MAQC
# you can use the following codes
\donttest{
insample <- data.frame("id" = c( "BRN_SRR037452", 
"BRN_SRR037453","BRN_SRR037454", "BRN_SRR037455", 
"BRN_SRR037456", "BRN_SRR037457", "BRN_SRR037458" 
 ), 
                     "path" = c(
"SRR037452_map.bam", "SRR037453_map.bam", "SRR037454_map.bam", 
"SRR037455_map.bam", "SRR037456_map.bam", "SRR037457_map.bam", 
"SRR037458_map.bam") ) 

#### chrMap is a simple vector with the chromosome names 
chrMap <- c(paste("chr", 1:22, sep = ""), "chrM", "chrX", "chrY")

#### annotation file for ENS59 protein coding genes
annotation <- read.table("ENS59_pcg_annotation.txt",  header=T)

allCounts <- prime.reweight.counts(insample, annotation, 
chrMap, group_fac = "Ensembl.Transcript.ID") 
}
}



% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.

